found_person_outcome

Function found_person_outcome 

fn found_person_outcome(claim: &ClaimedRegistration) -> Outcome
Leaves the row due for the enrolment lookup: a first resolve back in ready_to_submit, a parked row where it was, with its error code and last check time, since its enrolment was not checked.