pub(super) fn refused_person_decision(
code: CreditRegistrationErrorCode,
facts: &RowFacts,
) -> Decision<'static>Expand description
A person lookup Suotar answered with an error code, such as an unknown student number.
pub(super) fn refused_person_decision(
code: CreditRegistrationErrorCode,
facts: &RowFacts,
) -> Decision<'static>A person lookup Suotar answered with an error code, such as an unknown student number.