pub(super) fn unanswered_person_decision(
state: CreditRegistrationState,
facts: &RowFacts,
) -> Decision<'static>Expand description
A person lookup Suotar left unanswered for the row.
pub(super) fn unanswered_person_decision(
state: CreditRegistrationState,
facts: &RowFacts,
) -> Decision<'static>A person lookup Suotar left unanswered for the row.